@@ -212,7 +212,7 @@ def enable_python_hooks(ij):
 def prepare_deepslice_temp_folder(self):
     print('pdtf0')
     if not hasattr(self, '_run_deep_slice'):
-        from src.abba_python.abba_private.DeepSliceProcessor import DeepSliceProcessor
+        from abba_private.DeepSliceProcessor import DeepSliceProcessor
         self._run_deep_slice = DeepSliceProcessor()
 
     print('pdtf1')
